package com.github.fengyuchenglun.apidoc.core.common.convert;

import com.google.common.collect.Maps;

import java.sql.JDBCType;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.util.Map;
import java.util.Optional;
import java.util.concurrent.ConcurrentHashMap;

/**
 * The enum Field type convert.
 *
 * @author duanledexianxianxian
 */
public enum FieldTypeConvert implements IFieldTypeConvert {
    /**
     * String field type convert.
     */
    STRING("String", "String"),
    /**
     * Byte field type convert.
     */
    BYTE("Byte", "Byte"),
    /**
     * Short field type convert.
     */
    SHORT("Integer", "Short"),
    /**
     * Char field type convert.
     */
    CHAR("String", "Char"),
    /**
     * Int field type convert.
     */
    INT("Integer", "int"),
    /**
     * Long field type convert.
     */
    LONG("Long", "Long"),
    /**
     * Boolean field type convert.
     */
    BOOLEAN("Boolean", "Boolean"),
    /**
     * Float field type convert.
     */
    FLOAT("Float", "Float"),
    /**
     * Double field type convert.
     */
    DOUBLE("Double", "Double"),
    /**
     * Local date field type convert.
     */
    LOCAL_DATE("Date", "LocalDate"),
    /**
     * Local date time field type convert.
     */
    LOCAL_DATE_TIME("DateTime", "LocalDateTime"),
    /**
     * Local time field type convert.
     */
    LOCAL_TIME("Time", "LocalTime"),

    /**
     * Other field type convert.
     */
    OTHER("object", "Object"),
    ;

    /**
     * The Type.
     */
    private final String type;

    /**
     * The Java type.
     */
    private final String javaType;

    /**
     * Instantiates a new Field type convert.
     *
     * @param type     the type
     * @param javaType the java type
     */
    FieldTypeConvert(String type, String javaType) {
        this.type = type;
        this.javaType = javaType;
    }

    @Override
    public String getType() {
        return type;
    }

    @Override
    public String getJavaType() {
        return javaType;
    }

    /**
     * The Field type cache map.
     */
    private static Map<String, IFieldTypeConvert> FIELD_TYPE_CACHE_MAP = Maps.newConcurrentMap();

    static {
        for (IFieldTypeConvert fieldTypeConvert : FieldTypeConvert.values()) {
            FIELD_TYPE_CACHE_MAP.put(fieldTypeConvert.getJavaType().toLowerCase(), fieldTypeConvert);
        }
    }

    /**
     * Java type of field type convert.
     *
     * @param javaType the java type
     * @return the field type convert
     */
    public static IFieldTypeConvert javaTypeOf(String javaType) {
        return FIELD_TYPE_CACHE_MAP.get(javaType.toLowerCase());
    }
}
